EphemeralHandleBehavior

Enum EphemeralHandleBehavior 

pub enum EphemeralHandleBehavior {
    Silent,
    Warn,
    Error,
}
Specifies the action that will be taken when attempting to serialize an ephemeral handle.

Ephemeral handles are handles to assets that were not loaded. Specifically, these are handles to assets that were manually added.

Variants



Silent

Ephemeral handles are entirely ignored and are serialized as the default Handle.



Warn

A warning is logged, and the handle is serialized as the default Handle.



Error

Serializing an ephemeral handle will cause serialization to return an error.