AssetMut

Struct AssetMut 

pub struct AssetMut<'a, A: Asset> { /* private fields */ }
Unique mutable borrow of an asset.

AssetEvent::Modified events will be only triggered if an asset itself is mutably borrowed.

Just as an example, this allows checking if a material property has changed before modifying it to avoid unnecessary material extraction down the pipeline.

Implementations

Source

impl<'a, A: Asset> AssetMut<'a, A>

pub fn into_inner(self) -> &'a mut A

Marks with inner asset as modified and returns reference to it.

pub fn into_inner_untracked(self) -> &'a mut A

Returns reference to the inner asset but doesn’t mark it as modified.

pub fn bypass_change_detection(&mut self) -> &mut A

Manually bypasses change detection, allowing you to mutate the underlying value without emitting AssetEvent::Modified event.

Warning

This is a risky operation, that can have unexpected consequences on any system relying on this code. However, it can be an essential escape hatch when, for example, you are trying to synchronize representations using change detection and need to avoid infinite recursion.