pub struct ErasedLoadedAsset { /* private fields */ }Expand description
A “type erased / boxed” counterpart to LoadedAsset. This is used in places where the loaded type is not statically known.
Implementations
Sourceimpl ErasedLoadedAsset
impl ErasedLoadedAsset
Sourcepub fn asset_type_id(&self) -> TypeId
pub fn asset_type_id(&self) -> TypeId
Sourcepub fn asset_type_name(&self) -> &'static str
pub fn asset_type_name(&self) -> &'static str
Retrieves the type_name of the stored Asset type.
Sourcepub fn get_labeled(&self, label: impl AsRef<str>) -> Option<&ErasedLoadedAsset>
pub fn get_labeled(&self, label: impl AsRef<str>) -> Option<&ErasedLoadedAsset>
Returns the ErasedLoadedAsset for the given label, if it exists.
Sourcepub fn get_labeled_by_id(
&self,
id: impl Into<UntypedAssetId>,
) -> Option<&ErasedLoadedAsset>
pub fn get_labeled_by_id( &self, id: impl Into<UntypedAssetId>, ) -> Option<&ErasedLoadedAsset>
Returns the labeled asset given its asset ID if it exists.
This can be used to get the asset from its handle since &Handle implements
Into<UntypedAssetId>.
Sourcepub fn iter_labels(&self) -> impl Iterator<Item = &str>
pub fn iter_labels(&self) -> impl Iterator<Item = &str>
Iterate over all labels for “labeled assets” in the loaded asset
Sourcepub fn downcast<A: Asset>(self) -> Result<LoadedAsset<A>, ErasedLoadedAsset>
pub fn downcast<A: Asset>(self) -> Result<LoadedAsset<A>, ErasedLoadedAsset>
Cast this loaded asset as the given type. If the type does not match, the original type-erased asset is returned.