HandleDeserializeProcessor

Struct HandleDeserializeProcessor 

pub struct HandleDeserializeProcessor<'a> {
    pub load_from_path: &'a mut dyn LoadFromPath,
}
A ReflectDeserializerProcessor that manually deserializes Handle and UntypedHandle, and passes through for all other types.

Handles cannot be deserialized normally since it contains lots of ephemeral information (e.g., the AssetId of the asset being referenced). This processor deserializes the identifying and stable parts of the handle (usually serialized by HandleSerializeProcessor), and triggers the load of that handle.

Use HandleSerializeProcessor to serialize data for this processor.

Fields

load_from_path: &'a mut dyn LoadFromPath

The loader to load asset paths and retrieve their handles.