pub struct TypedHandleReference {
pub asset_type: Cow<'static, str>,
pub reference: HandleReference,
}Expand description
The “stable” data of a handle whose asset type information is stored internally.
Fields
asset_type: Cow<'static, str>The type path of the asset type this handle references.
reference: HandleReferenceThe reference for this handle.