pub struct HandleSerializeProcessor {
pub ephemeral_handle_behavior: EphemeralHandleBehavior,
}Expand description
A ReflectSerializerProcessor that manually serializes Handle and UntypedHandle, and
passes through for all other types.
Handles cannot be serialized normally since it contains lots of ephemeral information (e.g.,
the AssetId of the asset being referenced). This processor serializes just the identifying
and stable parts of the handle. This can later be used to deserialize the handle.
Use HandleDeserializeProcessor to deserialize this data.
Fields
ephemeral_handle_behavior: EphemeralHandleBehaviorHow ephemeral handles are dealt with.