pub struct NestedLoadBuilder<'ctx, 'builder> { /* private fields */ }Expand description
A builder for loading nested assets inside a LoadContext.
Implementations
Sourceimpl<'ctx, 'builder> NestedLoadBuilder<'ctx, 'builder>
impl<'ctx, 'builder> NestedLoadBuilder<'ctx, 'builder>
Sourcepub fn with_settings<S: Settings>(
self,
settings: impl Fn(&mut S) + Send + Sync + 'static,
) -> Self
pub fn with_settings<S: Settings>( self, settings: impl Fn(&mut S) + Send + Sync + 'static, ) -> Self
Use the given settings function to override the asset’s AssetLoader settings.
The type S must match the configured AssetLoader::Settings or settings changes will
be ignored and an error will be printed to the log.
Repeatedly calling this method will “chain” the operations (matching the order of these calls).
Sourcepub fn override_unapproved(self) -> Self
pub fn override_unapproved(self) -> Self
Loads from unapproved paths are allowed, even if
AssetPlugin::unapproved_path_mode is
Deny.
Sourcepub fn load<'a, A: Asset>(self, path: impl Into<AssetPath<'a>>) -> Handle<A>
pub fn load<'a, A: Asset>(self, path: impl Into<AssetPath<'a>>) -> Handle<A>
Loads the provided path as the given type and returns the handle.
This is a “deferred” load, meaning the caller will not have access to the loaded data; to
access the loaded data, use Self::load_value.
Sourcepub fn load_erased<'a>(
self,
type_id: TypeId,
path: impl Into<AssetPath<'a>>,
) -> UntypedHandle
pub fn load_erased<'a>( self, type_id: TypeId, path: impl Into<AssetPath<'a>>, ) -> UntypedHandle
Loads the provided path as the given type and returns the handle.
This is a “deferred” load, meaning the caller will not have access to the loaded data; to
access the loaded data, use Self::load_erased_value.
Sourcepub fn load_untyped<'a>(
self,
path: impl Into<AssetPath<'a>>,
) -> Handle<LoadedUntypedAsset>
pub fn load_untyped<'a>( self, path: impl Into<AssetPath<'a>>, ) -> Handle<LoadedUntypedAsset>
Loads the provided path with an unknown type (which is guessed based on the path or meta file).
This is a “deferred” load, meaning the caller will not have access to the loaded data; to
access the loaded data, use Self::load_untyped_value.
Sourcepub async fn load_value<'a, A: Asset>(
self,
path: impl Into<AssetPath<'a>>,
) -> Result<LoadedAsset<A>, LoadDirectError>
pub async fn load_value<'a, A: Asset>( self, path: impl Into<AssetPath<'a>>, ) -> Result<LoadedAsset<A>, LoadDirectError>
Loads the provided path as the given type, returning the loaded data.
This load is async and therefore needs to be awaited before returning the loaded data.
Sourcepub async fn load_erased_value<'a>(
self,
type_id: TypeId,
path: impl Into<AssetPath<'a>>,
) -> Result<ErasedLoadedAsset, LoadDirectError>
pub async fn load_erased_value<'a>( self, type_id: TypeId, path: impl Into<AssetPath<'a>>, ) -> Result<ErasedLoadedAsset, LoadDirectError>
Loads the provided path as the given type, returning the loaded data.
This load is async and therefore needs to be awaited before returning the loaded data.
Sourcepub async fn load_untyped_value<'a>(
self,
path: impl Into<AssetPath<'a>>,
) -> Result<ErasedLoadedAsset, LoadDirectError>
pub async fn load_untyped_value<'a>( self, path: impl Into<AssetPath<'a>>, ) -> Result<ErasedLoadedAsset, LoadDirectError>
Loads the provided path with an unknown type (which is guessed based on the path or meta file), returning the loaded data.
This load is async and therefore needs to be awaited before returning the loaded data.
Sourcepub async fn load_value_from_reader<'a, A: Asset>(
self,
path: impl Into<AssetPath<'a>>,
reader: &'builder mut dyn Reader,
) -> Result<LoadedAsset<A>, LoadDirectError>
pub async fn load_value_from_reader<'a, A: Asset>( self, path: impl Into<AssetPath<'a>>, reader: &'builder mut dyn Reader, ) -> Result<LoadedAsset<A>, LoadDirectError>
Loads the given type from the given reader, returning the loaded data.
This load is async and therefore needs to be awaited before returning the loaded data. The provided path determines the path used for handles of subassets, as well as any relative paths of assets used by the nested loader.
Sourcepub async fn load_erased_value_from_reader<'a>(
self,
type_id: TypeId,
path: impl Into<AssetPath<'a>>,
reader: &'builder mut dyn Reader,
) -> Result<ErasedLoadedAsset, LoadDirectError>
pub async fn load_erased_value_from_reader<'a>( self, type_id: TypeId, path: impl Into<AssetPath<'a>>, reader: &'builder mut dyn Reader, ) -> Result<ErasedLoadedAsset, LoadDirectError>
Loads the given type from the given reader, returning the loaded data.
This load is async and therefore needs to be awaited before returning the loaded data. The provided path determines the path used for handles of subassets, as well as any relative paths of assets used by the nested loader.
Sourcepub async fn load_untyped_value_from_reader<'a>(
self,
path: impl Into<AssetPath<'a>>,
reader: &'builder mut dyn Reader,
) -> Result<ErasedLoadedAsset, LoadDirectError>
pub async fn load_untyped_value_from_reader<'a>( self, path: impl Into<AssetPath<'a>>, reader: &'builder mut dyn Reader, ) -> Result<ErasedLoadedAsset, LoadDirectError>
Loads an asset from the given reader with an unknown type (which is guessed based on the
path or meta file), returning the loaded data.
This load is async and therefore needs to be awaited before returning the loaded data. The provided path determines the path used for handles of subassets, as well as any relative paths of assets used by the nested loader.